Orange Bioinformatics documentation
===================================

Orange Bioinformatics is an add-on for Orange_ data mining software package. It
extends Orange by providing common functionality for basic tasks in
bioinformatics. It also provides widgets for Orange Canvas, which enable users
who are not programmers to manage microarray and genomic data flow and to
customize their analysis by combining common data analysis tools to fit their
needs.

.. _Orange: http://orange.biolab.si/

Widgets
-------

.. toctree::
   :maxdepth: 1
 
   PIPA.rst

Scripting Reference
-------------------
   
.. toctree::
   :maxdepth: 1

   reference/kegg.rst
   reference/ontology.rst
   reference/dictybase.rst

Installation
------------

To install Bioinformatics add-on for Orange from PyPi_ run::

    pip install Orange-Bioinformatics

To install it from source code run::

    python setup.py install

To build Python egg run::

    python setup.py bdist_egg

To install add-on in `development mode`_ run::

    python setup.py develop

.. _development mode: http://packages.python.org/distribute/setuptools.html#development-mode
.. _PyPi: http://pypi.python.org/pypi

Source Code and Issue Tracker
-----------------------------

Source code is available on Bitbucket_. For issues and wiki we use Trac_.

.. _Bitbucket: https://bitbucket.org/biolab/orange-bioinformatics
.. _Trac: http://orange.biolab.si/trac/

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
